Documentation
¶
Index ¶
Constants ¶
const ESC = 27
ESC is the ASCII code for escape character
Variables ¶
Functions ¶
This section is empty.
Types ¶
type Writer ¶
type Writer struct {
// contains filtered or unexported fields
}
Writer is a buffered the writer that updates the terminal. The contents of writer will be flushed when Flush is called.
func (*Writer) Flush ¶
Flush flushes the underlying buffer
func (*Writer) GetWidth ¶
GetWidth returns width of underlying terminal.
func (*Writer) ReadFrom ¶
ReadFrom reads from the provided io.Reader and writes to the underlying buffer.
func (*Writer) Write ¶
Write appends the contents of p to the underlying buffer
Source Files
¶
- writer.go
- writer_posix.go
Click to show internal directories.
Click to hide internal directories.